PiperTtsPlugin class

Constructors

PiperTtsPlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
isLoaded bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
loadViaPath({required String modelPath, required String configPath}) Future<void>
loadViaVoicePack(PiperVoicePack voicePack) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
synthesizeToFile({required String text, required String outputPath}) Future<File>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited